==> skasip_logging-1.0.3.tar.gz: skasip_logging-1.0.3/sip_logging/sip_logging.py <==
# coding: utf-8
"""Utility module for standardising python logging throughout SIP.

Usage:

```python
import logging
from sip_logging import init_logger

def foo():
    log = logging.getLogger('sip.foo')
    log.info('Hello')

if __name__ == '__main__':
     init_logger()
```

"""
import sys
import logging
import os
import datetime


class SIPFormatter(logging.Formatter):
    """Custom log formatter class to add microsecond precision timestamps."""

    converter = datetime.datetime.fromtimestamp

    def formatTime(self, record, datefmt=None):
        """Format the log timestamp."""
        _created = self.converter(record.created)
        if datefmt:
            time_string = _created.strftime(datefmt)
        else:
            time_string = _created.strftime("%Y-%m-%d %H:%M:%S")
            time_string = "%s,%03d" % (time_string, record.msecs)
        return time_string


def init_logger(log_level=None, p3_mode: bool = True):
    """Initialise the SIP logger.

    Attaches a stdout stream handler to the 'sip' logger. This will
    apply to all logger objects with a name prefixed by 'sip.'

    This function respects the 'SIP_LOG_LEVEL' environment variable to
    set the logging level.

    Args:
        log_level (str or int, optional): Logging level for the SIP logger.
        p3_mode (bool, optional): Print logging statements in a format that
                                  P3 can support.

    """
    log = logging.getLogger('sip')
    handler = logging.StreamHandler(stream=sys.stdout)
    if p3_mode:
        _format = '%(asctime)s.%(msecs)03d | %(name)s | %(levelname)-7s | ' \
                  '%(message)s'
        formatter = logging.Formatter(_format, '%Y-%m-%d %H:%M:%S')
    else:
        _format = '%(asctime)s | %(name)s | %(levelname)-7s | %(message)s'
        formatter = SIPFormatter(_format, datefmt='%Y-%m-%dT%H:%M:%S.%f')

    handler.setFormatter(formatter)
    log.addHandler(handler)
    if log_level:
        log.setLevel(log_level)
    else:
        log.setLevel(os.getenv('SIP_LOG_LEVEL', 'DEBUG'))

==> skasip_logging-1.0.5.tar.gz: skasip_logging-1.0.5/sip_logging/sip_logging.py <==
# coding: utf-8
"""Utility module for standardising python logging throughout SIP.

Usage:

```python
import logging
from sip_logging import init_logger

def foo():
    log = logging.getLogger('sip.foo')
    log.info('Hello')

if __name__ == '__main__':
     init_logger()
```

"""
import sys
import logging
import os
import datetime


class SIPFormatter(logging.Formatter):
    """Custom log formatter class to add microsecond precision timestamps."""

    converter = datetime.datetime.fromtimestamp

    def formatTime(self, record, datefmt=None):
        """Format the log timestamp."""
        _created = self.converter(record.created)
        if datefmt:
            time_string = _created.strftime(datefmt)
        else:
            time_string = _created.strftime("%Y-%m-%d %H:%M:%S")
            time_string = "%s,%03d" % (time_string, record.msecs)
        return time_string


def init_logger(log_level=None, p3_mode: bool = True,
                show_thread: bool = False):
    """Initialise the SIP logger.

    Attaches a stdout stream handler to the 'sip' logger. This will
    apply to all logger objects with a name prefixed by 'sip.'

    This function respects the 'SIP_LOG_LEVEL' environment variable to
    set the logging level.

    Args:
        log_level (str or int, optional): Logging level for the SIP logger.
        p3_mode (bool, optional): Print logging statements in a format that
                                  P3 can support.
        show_thread (bool, optional): Display the thread in the log message.

    """
    log = logging.getLogger('sip')
    handler = logging.StreamHandler(stream=sys.stdout)
    # Remove existing handlers (to avoid duplicate messages if the log is
    #                           initialised twice)
    for handler in log.handlers:
        log.removeHandler(handler)
    if p3_mode:
        if show_thread:
            _format = '%(asctime)s.%(msecs)03d | %(name)s ' \
                      '| %(levelname)-7s | %(threadName)-22s | %(message)s'
        else:
            _format = '%(asctime)s.%(msecs)03d | %(name)s ' \
                      '| %(levelname)-7s | %(message)s'
        formatter = logging.Formatter(_format, '%Y-%m-%d %H:%M:%S')
    else:
        if show_thread:
            _format = '%(asctime)s | %(name)s | %(levelname)-7s | ' \
                      '%(threadName)-22s | %(message)s'
        else:
            _format = '%(asctime)s | %(name)s | %(levelname)-7s | %(message)s'
        formatter = SIPFormatter(_format, datefmt='%Y-%m-%dT%H:%M:%S.%f')

    handler.setFormatter(formatter)
    log.addHandler(handler)
    if log_level:
        log.setLevel(log_level)
    else:
        log.setLevel(os.getenv('SIP_LOG_LEVEL', 'DEBUG'))
